@@ -8,6 +8,8 @@
 
 #include <libsoup/soup-types.h>
 
+G_BEGIN_DECLS
+
 typedef struct SoupMessageHeaders SoupMessageHeaders;
 GType soup_message_headers_get_type (void);
 #define SOUP_TYPE_MESSAGE_HEADERS (soup_message_headers_get_type ())
@@ -47,6 +49,14 @@ const char         *soup_message_headers_get_one  (SoupMessageHeaders *hdrs,
 SOUP_AVAILABLE_IN_2_28
 const char         *soup_message_headers_get_list (SoupMessageHeaders *hdrs,
 						   const char         *name);
+SOUP_AVAILABLE_IN_2_50
+gboolean            soup_message_headers_header_contains (SoupMessageHeaders *hdrs,
+							  const char         *name,
+							  const char         *token);
+SOUP_AVAILABLE_IN_2_50
+gboolean            soup_message_headers_header_equals   (SoupMessageHeaders *hdrs,
+							  const char         *name,
+							  const char         *value);
 
 typedef void      (*SoupMessageHeadersForeachFunc)(const char         *name,
 						   const char         *value,
@@ -56,6 +66,9 @@ void                soup_message_headers_foreach  (SoupMessageHeaders *hdrs,
 						   SoupMessageHeadersForeachFunc func,
 						   gpointer            user_data);
 
+SOUP_AVAILABLE_IN_2_50
+SoupMessageHeadersType soup_message_headers_get_headers_type (SoupMessageHeaders *hdrs);
+
 typedef struct {
 	/*< private >*/
 	gpointer dummy[3];
@@ -146,4 +159,6 @@ void     soup_message_headers_set_content_disposition (SoupMessageHeaders  *hdrs
 						       const char          *disposition,
 						       GHashTable          *params);
 
+G_END_DECLS
+
 #endif /* SOUP_MESSAGE_HEADERS_H */
